/* Used from libprelude headers */
#define HAVE_VARIADIC_MACROS 1
#define TIME_WITH_SYS_TIME 1
#define PRELUDE_ALIGNED_ACCESS 
#define PRELUDE_WORDS_BIGENDIAN 
#define __PRELUDE_FUNC__ __func__
